==> dawaR_0.2.4.tar.gz: dawaR/tests/testthat/_snaps/reverse.md <==
# reverse geocode returns information reliably

    Code
      reverse("regioner", x = 12.58515, y = 55.68324)
    Message
      > Requesting `regioner - reverse` from DAWA
    Output
      $ændret
      [1] "2024-10-04T21:02:54.978Z"
      
      $geo_version
      [1] 31
      
      $geo_ændret
      [1] "2024-10-04T21:02:54.978Z"
      
      $bbox
      $bbox[[1]]
      [1] 11.60212
      
      $bbox[[2]]
      [1] 54.98355
      
      $bbox[[3]]
      [1] 15.31831
      
      $bbox[[4]]
      [1] 56.2052
      
      
      $visueltcenter
      $visueltcenter[[1]]
      [1] 12.27937
      
      $visueltcenter[[2]]
      [1] 55.97239
      
      
      $dagi_id
      [1] "389099"
      
      $kode
      [1] "1084"
      
      $navn
      [1] "Region Hovedstaden"
      
      $nuts2
      [1] "DK01"
      
      $href
      [1] "https://api.dataforsyningen.dk/regioner/1084"
      

---

    Code
      reverse("afstemningsomraader", x = 10.2147102008892, y = 56.1535382215792)
    Message
      > Requesting `afstemningsomraader - reverse` from DAWA
    Output
      $ændret
      [1] "2024-05-08T21:01:09.316Z"
      
      $geo_version
      [1] 7
      
      $geo_ændret
      [1] "2024-05-08T21:01:09.316Z"
      
      $bbox
      $bbox[[1]]
      [1] 10.203
      
      $bbox[[2]]
      [1] 56.14667
      
      $bbox[[3]]
      [1] 10.22323
      
      $bbox[[4]]
      [1] 56.17079
      
      
      $visueltcenter
      $visueltcenter[[1]]
      [1] 10.21425
      
      $visueltcenter[[2]]
      [1] 56.16615
      
      
      $href
      [1] "https://api.dataforsyningen.dk/afstemningsomraader/751/10"
      
      $dagi_id
      [1] "708544"
      
      $nummer
      [1] "10"
      
      $navn
      [1] "DOKK1"
      
      $afstemningssted
      $afstemningssted$navn
      [1] "DOKK1"
      
      $afstemningssted$adgangsadresse
      $afstemningssted$adgangsadresse$href
      [1] "https://api.dataforsyningen.dk/adgangsadresser/c1496b42-51c0-48ed-afc7-b340ac97ae13"
      
      $afstemningssted$adgangsadresse$id
      [1] "c1496b42-51c0-48ed-afc7-b340ac97ae13"
      
      $afstemningssted$adgangsadresse$adressebetegnelse
      [1] "Hack Kampmanns Plads 2, 8000 Aarhus C"
      
      $afstemningssted$adgangsadresse$koordinater
      $afstemningssted$adgangsadresse$koordinater[[1]]
      [1] 10.21378
      
      $afstemningssted$adgangsadresse$koordinater[[2]]
      [1] 56.15344
      
      
      
      
      $kommune
      $kommune$href
      [1] "https://api.dataforsyningen.dk/kommuner/0751"
      
      $kommune$kode
      [1] "0751"
      
      $kommune$navn
      [1] "Aarhus"
      
      
      $region
      $region$href
      [1] "https://api.dataforsyningen.dk/regioner/1082"
      
      $region$kode
      [1] "1082"
      
      $region$navn
      [1] "Region Midtjylland"
      
      
      $opstillingskreds
      $opstillingskreds$href
      [1] "https://api.dataforsyningen.dk/opstillingskredse/65"
      
      $opstillingskreds$nummer
      [1] "65"
      
      $opstillingskreds$navn
      [1] "Aarhus Øst"
      
      
      $storkreds
      $storkreds$href
      [1] "https://api.dataforsyningen.dk/storkredse/8"
      
      $storkreds$nummer
      [1] "8"
      
      $storkreds$navn
      [1] "Østjylland"
      
      
      $valglandsdel
      $valglandsdel$href
      [1] "https://api.dataforsyningen.dk/valglandsdele/C"
      
      $valglandsdel$bogstav
      [1] "C"
      
      $valglandsdel$navn
      [1] "Midtjylland-Nordjylland"
      
      

---

    Code
      reverse("regioner", y = 56.9605461150057, x = 9.28423598747354)
    Message
      > Requesting `regioner - reverse` from DAWA
    Output
      $ændret
      [1] "2024-10-04T21:02:54.978Z"
      
      $geo_version
      [1] 32
      
      $geo_ændret
      [1] "2024-10-04T21:02:54.978Z"
      
      $bbox
      $bbox[[1]]
      [1] 8.189517
      
      $bbox[[2]]
      [1] 56.53455
      
      $bbox[[3]]
      [1] 11.22599
      
      $bbox[[4]]
      [1] 57.76025
      
      
      $visueltcenter
      $visueltcenter[[1]]
      [1] 10.11283
      
      $visueltcenter[[2]]
      [1] 57.30716
      
      
      $dagi_id
      [1] "389098"
      
      $kode
      [1] "1081"
      
      $navn
      [1] "Region Nordjylland"
      
      $nuts2
      [1] "DK05"
      
      $href
      [1] "https://api.dataforsyningen.dk/regioner/1081"
      

---

    Code
      reverse("politikredse", y = 55.3230944206779, x = 11.5534117505933)
    Message
      > Requesting `politikredse - reverse` from DAWA
    Output
      $ændret
      [1] "2024-10-22T21:04:04.354Z"
      
      $geo_version
      [1] 18
      
      $geo_ændret
      [1] "2024-10-22T21:04:04.354Z"
      
      $bbox
      $bbox[[1]]
      [1] 10.90937
      
      $bbox[[2]]
      [1] 54.54441
      
      $bbox[[3]]
      [1] 12.6071
      
      $bbox[[4]]
      [1] 55.60197
      
      
      $visueltcenter
      $visueltcenter[[1]]
      [1] 11.49387
      
      $visueltcenter[[2]]
      [1] 55.35124
      
      
      $dagi_id
      [1] "403211"
      
      $kode
      [1] "1466"
      
      $navn
      [1] "Sydsjællands og Lolland-Falsters Politi"
      
      $href
      [1] "https://api.dataforsyningen.dk/politikredse/1466"

==> dawaR_0.3.0.tar.gz: dawaR/tests/testthat/_snaps/reverse.md <==
# reverse geocode regioner 1

    Code
      reverse("regioner", x = 12.58515, y = 55.68324)
    Message
      > Requesting `regioner - reverse` from DAWA
    Output
      $ændret
      [1] "2024-10-04T21:02:54.978Z"
      
      $geo_version
      [1] 31
      
      $geo_ændret
      [1] "2024-10-04T21:02:54.978Z"
      
      $bbox
      $bbox[[1]]
      [1] 11.60212
      
      $bbox[[2]]
      [1] 54.98355
      
      $bbox[[3]]
      [1] 15.31831
      
      $bbox[[4]]
      [1] 56.2052
      
      
      $visueltcenter
      $visueltcenter[[1]]
      [1] 12.27937
      
      $visueltcenter[[2]]
      [1] 55.97239
      
      
      $dagi_id
      [1] "389099"
      
      $kode
      [1] "1084"
      
      $navn
      [1] "Region Hovedstaden"
      
      $nuts2
      [1] "DK01"
      
      $href
      [1] "https://api.dataforsyningen.dk/regioner/1084"
      

# reverse geocode afstemningsomraader

    Code
      reverse("afstemningsomraader", x = 10.2147102008892, y = 56.1535382215792)
    Message
      > Requesting `afstemningsomraader - reverse` from DAWA
    Output
      $ændret
      [1] "2024-05-08T21:01:09.316Z"
      
      $geo_version
      [1] 7
      
      $geo_ændret
      [1] "2024-05-08T21:01:09.316Z"
      
      $bbox
      $bbox[[1]]
      [1] 10.203
      
      $bbox[[2]]
      [1] 56.14667
      
      $bbox[[3]]
      [1] 10.22323
      
      $bbox[[4]]
      [1] 56.17079
      
      
      $visueltcenter
      $visueltcenter[[1]]
      [1] 10.21425
      
      $visueltcenter[[2]]
      [1] 56.16615
      
      
      $href
      [1] "https://api.dataforsyningen.dk/afstemningsomraader/751/10"
      
      $dagi_id
      [1] "708544"
      
      $nummer
      [1] "10"
      
      $navn
      [1] "DOKK1"
      
      $afstemningssted
      $afstemningssted$navn
      [1] "DOKK1"
      
      $afstemningssted$adgangsadresse
      $afstemningssted$adgangsadresse$href
      [1] "https://api.dataforsyningen.dk/adgangsadresser/c1496b42-51c0-48ed-afc7-b340ac97ae13"
      
      $afstemningssted$adgangsadresse$id
      [1] "c1496b42-51c0-48ed-afc7-b340ac97ae13"
      
      $afstemningssted$adgangsadresse$adressebetegnelse
      [1] "Hack Kampmanns Plads 2, 8000 Aarhus C"
      
      $afstemningssted$adgangsadresse$koordinater
      $afstemningssted$adgangsadresse$koordinater[[1]]
      [1] 10.21378
      
      $afstemningssted$adgangsadresse$koordinater[[2]]
      [1] 56.15344
      
      
      
      
      $kommune
      $kommune$href
      [1] "https://api.dataforsyningen.dk/kommuner/0751"
      
      $kommune$kode
      [1] "0751"
      
      $kommune$navn
      [1] "Aarhus"
      
      
      $region
      $region$href
      [1] "https://api.dataforsyningen.dk/regioner/1082"
      
      $region$kode
      [1] "1082"
      
      $region$navn
      [1] "Region Midtjylland"
      
      
      $opstillingskreds
      $opstillingskreds$href
      [1] "https://api.dataforsyningen.dk/opstillingskredse/65"
      
      $opstillingskreds$nummer
      [1] "65"
      
      $opstillingskreds$navn
      [1] "Aarhus Øst"
      
      
      $storkreds
      $storkreds$href
      [1] "https://api.dataforsyningen.dk/storkredse/8"
      
      $storkreds$nummer
      [1] "8"
      
      $storkreds$navn
      [1] "Østjylland"
      
      
      $valglandsdel
      $valglandsdel$href
      [1] "https://api.dataforsyningen.dk/valglandsdele/C"
      
      $valglandsdel$bogstav
      [1] "C"
      
      $valglandsdel$navn
      [1] "Midtjylland-Nordjylland"
      
      

# reverse geocode regioner 2

    Code
      reverse("regioner", y = 56.9605461150057, x = 9.28423598747354)
    Message
      > Requesting `regioner - reverse` from DAWA
    Output
      $ændret
      [1] "2024-10-04T21:02:54.978Z"
      
      $geo_version
      [1] 32
      
      $geo_ændret
      [1] "2024-10-04T21:02:54.978Z"
      
      $bbox
      $bbox[[1]]
      [1] 8.189517
      
      $bbox[[2]]
      [1] 56.53455
      
      $bbox[[3]]
      [1] 11.22599
      
      $bbox[[4]]
      [1] 57.76025
      
      
      $visueltcenter
      $visueltcenter[[1]]
      [1] 10.11283
      
      $visueltcenter[[2]]
      [1] 57.30716
      
      
      $dagi_id
      [1] "389098"
      
      $kode
      [1] "1081"
      
      $navn
      [1] "Region Nordjylland"
      
      $nuts2
      [1] "DK05"
      
      $href
      [1] "https://api.dataforsyningen.dk/regioner/1081"
      

# reverse geocode politikredse

    Code
      reverse("politikredse", y = 55.3230944206779, x = 11.5534117505933)
    Message
      > Requesting `politikredse - reverse` from DAWA
    Output
      $ændret
      [1] "2024-10-22T21:04:04.354Z"
      
      $geo_version
      [1] 18
      
      $geo_ændret
      [1] "2024-10-22T21:04:04.354Z"
      
      $bbox
      $bbox[[1]]
      [1] 10.90937
      
      $bbox[[2]]
      [1] 54.54441
      
      $bbox[[3]]
      [1] 12.6071
      
      $bbox[[4]]
      [1] 55.60197
      
      
      $visueltcenter
      $visueltcenter[[1]]
      [1] 11.49387
      
      $visueltcenter[[2]]
      [1] 55.35124
      
      
      $dagi_id
      [1] "403211"
      
      $kode
      [1] "1466"
      
      $navn
      [1] "Sydsjællands og Lolland-Falsters Politi"
      
      $href
      [1] "https://api.dataforsyningen.dk/politikredse/1466"
      

# reverse geocode regioner error

    Code
      reverse("regioner", y = 47.8703370940483, x = 15.7457353678998, verbose = FALSE)
    Message
      x Request failed: HTTP 404 Not Found.
      x The API returned a  error.
      x No content will be returned
    Output
      NULL
